@@ -14,7 +14,7 @@ class Kraken2(Tool):
     The Kraken2 implementation of the Tool class.
     """
     def __init__(self, tool_args, output_name, inputs, output_path,
-                 database_name, database_version, custom_database_path):
+                 database_name, database_version, custom_database_path, **kwargs):
         super().__init__(
             tool_name="kraken2",
             tool_version="2.1.1",  # todo: allow kraken 2 version to be set by the user
@@ -31,5 +31,6 @@ class Kraken2(Tool):
             parallel_enabled=False,
             output_type=OutputType.S3 if path_is_s3_uri(output_path) else OutputType.GZ_TAR,
             output_is_directory=True,
-            output_names=["kraken2_output.txt", "kraken2_report.txt"]
+            output_names=["kraken2_output.txt", "kraken2_report.txt"],
+            **kwargs,
         )
