@@ -14,7 +14,7 @@ class Unicycler(Tool):
     The unicycler implementation of the Tool class.
     """
     def __init__(self, tool_args, output_name, inputs, input_prefix_mapping,
-                 output_path):
+                 output_path, **kwargs):
         super().__init__(
             tool_name="unicycler",
             tool_version="0.4.9",  # todo: allow unicycler version to be set by the user
@@ -29,4 +29,5 @@ class Unicycler(Tool):
             output_type=OutputType.GZ_TAR,
             output_is_directory=True,
             output_names=["assembly.fasta", "unicycler.log"],
+            **kwargs,
         )
